@@ -75,6 +75,7 @@ class BaseBucketer(BaseEstimator, TransformerMixin, PlotBucketMethod, BucketTabl
             "least_risky",
             "neutral",
             "similar",
+            "passthrough",
         ]
 
         if type(missing_treatment) == str:
@@ -178,6 +179,13 @@ class BaseBucketer(BaseEstimator, TransformerMixin, PlotBucketMethod, BucketTabl
                 table[table["label"] != "Missing"].sort_values("New_WoE").reset_index(drop=True).iloc[0]["bucket_id"]
             )
 
+        elif self.missing_treatment in ["passthrough"]:
+            missing_bucket = np.nan
+
+        else:
+            raise AssertionError(f"Invalid missing treatment '{self.missing_treatment}' specified")
+
+
         return missing_bucket
 
     def _filter_na_for_fit(self, X: pd.DataFrame, y):
@@ -283,6 +291,7 @@ class BaseBucketer(BaseEstimator, TransformerMixin, PlotBucketMethod, BucketTabl
             "least_risky",
             "neutral",
             "similar",
+            "passthrough",
         ]:
             missing_bucket = None
         if isinstance(self.missing_treatment, dict):
@@ -311,6 +320,7 @@ class BaseBucketer(BaseEstimator, TransformerMixin, PlotBucketMethod, BucketTabl
             "least_risky",
             "neutral",
             "similar",
+            "passthrough",
         ]:
             missing_bucket = self._find_missing_bucket(feature=feature)
             # Repeat above procedure now we know the bucket distribution
