@@ -14,7 +14,7 @@ from skorecard.features_bucket_mapping import FeaturesBucketMapping
 from skorecard.reporting import build_bucket_table
 from skorecard.utils import NotInstalledError, NotPreBucketedError
 from skorecard.utils.exceptions import ApproximationWarning
-from skorecard.utils.validation import ensure_dataframe
+from skorecard.utils.validation import check_args, ensure_dataframe
 
 try:
     from optbinning import OptimalBinning
@@ -82,6 +82,7 @@ class OptimalBucketer(BaseBucketer):
                     most_frequent: Missing values are put into the most common bucket.
                     neutral: Missing values are put into the bucket with WoE closest to 0.
                     similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
+                    passthrough: Leaves missing values untouched.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values.
@@ -128,6 +129,8 @@ class OptimalBucketer(BaseBucketer):
         self.gamma = gamma
         self.ob_kwargs = ob_kwargs
 
+        check_args(ob_kwargs, OptimalBinning)
+
     def _get_feature_splits(self, feature, X, y, X_unfiltered=None):
         """
         Finds the splits for a single feature.
@@ -244,6 +247,7 @@ class EqualWidthBucketer(BaseBucketer):
                     most_frequent: Missing values are put into the most common bucket.
                     neutral: Missing values are put into the bucket with WoE closest to 0.
                     similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
+                    passthrough: Leaves missing values untouched.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values.
@@ -343,6 +347,7 @@ class AgglomerativeClusteringBucketer(BaseBucketer):
                     most_frequent: Missing values are put into the most common bucket.
                     neutral: Missing values are put into the bucket with WoE closest to 0.
                     similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
+                    passthrough: Leaves missing values untouched.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values.
@@ -448,6 +453,7 @@ class EqualFrequencyBucketer(BaseBucketer):
                     most_frequent: Missing values are put into the most common bucket.
                     neutral: Missing values are put into the bucket with WoE closest to 0.
                     similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
+                    passthrough: Leaves missing values untouched.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values..
@@ -576,6 +582,7 @@ class DecisionTreeBucketer(BaseBucketer):
                     most_frequent: Missing values are put into the most common bucket.
                     neutral: Missing values are put into the bucket with WoE closest to 0.
                     similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
+                    passthrough: Leaves missing values untouched.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values.
@@ -594,6 +601,8 @@ class DecisionTreeBucketer(BaseBucketer):
         self.random_state = random_state
         self.remainder = remainder
 
+        check_args(dt_kwargs, DecisionTreeClassifier)
+
     @property
     def variables_type(self):
         """
@@ -729,6 +738,7 @@ class OrdinalCategoricalBucketer(BaseBucketer):
                     most_frequent: Missing values are put into the most common bucket.
                     neutral: Missing values are put into the bucket with WoE closest to 0.
                     similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
+                    passthrough: Leaves missing values untouched.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values.
@@ -852,6 +862,7 @@ class AsIsCategoricalBucketer(BaseBucketer):
                     most_frequent: Missing values are put into the most common bucket.
                     neutral: Missing values are put into the bucket with WoE closest to 0.
                     similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
+                    passthrough: Leaves missing values untouched.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values.
@@ -945,6 +956,7 @@ class AsIsNumericalBucketer(BaseBucketer):
                     most_frequent: Missing values are put into the most common bucket.
                     neutral: Missing values are put into the bucket with WoE closest to 0.
                     similar: Missing values are put into the bucket with WoE closest to the bucket with only missing values.
+                    passthrough: Leaves missing values untouched.
                 If a dict, it must be of the following format:
                     {"<column name>": <bucket_number>}
                     This bucket number is where we will put the missing values..
